Estimates of correlation parameters and precision matrix
heterlongraph(data, rho, type, tole, lower, upper)Data matrix in which the first column is subject id, the second column is the time points of observation. Columns 2 to (p+2) is the observations for p variables.
Tuning parameter used in graphical lasso
Type of correlation function, which can take either "abs" or "sqr".
Error tolerance for determination of convergence of EM algorithm
Lower bound for prediction of correlation parameter tau
Upper bound for prediction of correlation parameter tau
S list with three components which are the final estimate of alpha, tau and precision matrix omega