Estiamte of precision matrix and autocorrelaton parameter for homogeneous model
homolongraph(data, rho, type, tole, lower, upper)Data matrix in which the first column is subject id, the second column is the time points of observation. Columns 2 to (p+2) is the observations for p variables.
Tuning parameter for graphical lasso
Type of correlation function, which can take either "abs" or "qua".
Error tolerance for determination of convergence of EM algorithm
Lower bound for prediction of correlation parameter tau
Upper bound for prediction of correlation parameter tau
A list for estimates of precision matrix and correlation parameter for given tuning parameter