Quasi covariance matrix for subject i
iss(idata, itau, type)Data matrix for the subject i in which the first column is subject (cluster) id, the second column stands for the time points () of observation. Columns 2 to (p+2) is the observations for p variables respectively.
Correlation parameter
Type of correlation function, which typically take either 0, 1 or 2.
Empirical quasi covariance matrix