Learn R Programming

lglasso (version 0.1.0)

ll_homo: Value of likelihood function at given parameter

Description

Value of likelihood function at given parameter

Usage

ll_homo(data, omega, tau, type)

Arguments

data

Data matrix in which the first column is subject id, the second column is the time points of observation. Columns 2 to (p+2) is the observations for p variables.

omega

Precision matrix

tau

Correlation parameter

type

Type of correlation function, which can take either "abs" or "qua".

Value

Value of likelihood function at given omega and tau