full log likelihood used in EBIC computation
lli_homo(idata, omega, tau, type)Data matrix for the subject i in which the first column is id for subject, the second column is the time points of observation. Columns 2 to (p+2) is the observations for p variables.
Precision matrix
Correlation parameter
Type of correlation function, which can take either "abs" or "qua".
Value of likelihood function for subject i at given omega and tau