Maximum likelihood estimate of correlation parameter for given structure of precision matrix
mle_alpha(data, alpha0, omega, type, tole, lower, upper)Data matrix in which the first column is subject id, the second column is the time points of observation. Columns 2 to (p+2) is the observations for p variables.
Initial value for the parameter in exponential distribution
Fixed value for precision matrix
Type of correlation function, which can take either "abs" or "qua".
Error tolerance for determination of convergence of EM algorithm
Lower bound for prediction of correlation parameter tau
Upper bound for prediction of correlation parameter tau