Estiamte of precision matrix and autocorrelaton parameter for homogeneous model
mle_tau(data, omega, type, lower, upper)Data matrix in which the first column is subject id, the second column is the time points of observation. Columns 2 to (p+2) is the observations for p variables.
The maximum likelihood estiamte of precision matrix
Type of correlation function, which can take either "abs" or "qua".
Lower bound for prediction of correlation parameter tau
Upper bound for prediction of correlation parameter tau
A list for estimates of precision matrix and correlation parameter for given tuning parameter