phifunction: Construct the temporal component fo correlation function
Description
Construct the temporal component fo correlation function
Usage
phifunction(t, tau, type = 1)
Arguments
t
Time points of observations
type
The type of correlation function, which typically take either 0,1 or 2.
Value
A square matrix with dimension equal to the length of vector t