Value of likelihood function at given parameter
ll_homo(data, omega, tau, type)Data matrix in which the first column is subject id, the second column is the time points of observation. Columns 2 to (p+2) is the observations for p variables.
Precision matrix
Correlation parameter
Type of correlation function, which can take either "abs" or "qua".
Value of likelihood function at given omega and tau