Maximum Likelihood Estimate of Precision Matrix and Correlation Parameters for Given Network
mle(
data,
network,
heter = TRUE,
type = 1,
tole = 0.01,
lower = 0.01,
upper = 10
)Data matrix in which the first column is subject id, the second column is
time points of observations for temporal data or site id for spatial data.
Columns 3 to (p+2) is the observations for p variables.
The network selected by function lglasso
Binary variable TRUE or FALSE, indicating heterogeneous model or homogeneous model is fitted. In heterogeneous model,
subjects are allowed to have his/her own temporal correlation parameter tau_i; while in homogeneous model, all the subjects are assumed to
share the same temporal correlation parameter,i.e., tau_1=tau_2=...tau_m.
A positive number which specify the correlation function. The general form of correlation function is given by exp(tau|t_i-t_j|^type).
in which type=0 can be used for spatial correlation while type>0 are used for temporal correlation. For latter, the default value is set to be type=1.
Threshold for convergence. Default value is 1e-2. Iterations stop when maximum
absolute difference between consecutive estimates of parameter change is less than tole.
Lower bound for predicts of correlation parameter tau.
Default value is 1e-2. The estimate of tau(alpha) will be searched in the
interval [lower,upper], where parameter upper is explained in the following.
Upper bound for predicts of correlation parameter tau.
A list which include the maximum likelihood estimate of precision matrix, correlation parameter tau. If heter=TRUE,
the output also include the estimate of alpha where tau~exp(alpha)